# API Reference

## Factory Function

### create_extractor

The main entry point for creating extractors.

::: unifex.create_extractor

## Extractor Types

### ExtractorType

Enum for available extractor types.

::: unifex.ExtractorType

## Coordinate Units

### CoordinateUnit

Enum for coordinate output units.

::: unifex.CoordinateUnit

## Executor Types

### ExecutorType

Enum for parallel execution modes.

::: unifex.base.ExecutorType
